@@ -12,12 +12,12 @@
 """
 These data types are used throughout the :mod:`pumpkin_supmcu.supmcu` to type and structure the module definitions.
 """
-from enum import Enum
-from typing import NamedTuple, Dict, Any, List
+from enum import IntEnum
+from typing import Dict, Any, List
 from dataclasses import dataclass
 
 
-class DataType(Enum):
+class DataType(IntEnum):
     """
     Different possible data types that can be returned from SupMCU Telemetry
     """
@@ -51,7 +51,7 @@ class DataType(Enum):
     """A `uint16_t` item, displayed as a hexadecimal value."""
 
 
-class TelemetryType(Enum):
+class TelemetryType(IntEnum):
     """Represents a module request for the SUP:TEL? items or MOD:TEL? items."""
     SupMCU = 0
     """SupMCU telemetry item (e.g. SUP:TEL? #)"""
